@@ -9,6 +9,7 @@
 VM=$1
 MODE=$2
 KOLLA_PATH=$3
+KOLLA_ANSIBLE_PATH=$4
 
 export http_proxy=
 export https_proxy=
@@ -75,7 +76,7 @@ function prep_work {
         exit 1
     fi
 
-    pip install --upgrade docker-py
+    pip install --upgrade docker
 }
 
 # Do some cleanup after the installation of kolla
@@ -114,10 +115,10 @@ EOF
         usermod -aG docker vagrant
     elif is_ubuntu; then
         apt-key adv --keyserver hkp://pgp.mit.edu:80 --recv-keys 58118E89F3A912897C070ADBF76221572C52609D
-        echo "deb https://apt.dockerproject.org/repo ubuntu-wily main" > /etc/apt/sources.list.d/docker.list
+        echo "deb https://apt.dockerproject.org/repo ubuntu-xenial main" > /etc/apt/sources.list.d/docker.list
         apt-get update
         apt-get -y install docker-engine
-        sed -i -r "s,(ExecStart)=(.+),\1=/usr/bin/docker daemon --insecure-registry ${REGISTRY} --registry-mirror=http://${REGISTRY}|" /lib/systemd/system/docker.service
+        sed -i -r "s|(ExecStart)=(.+)|\1=/usr/bin/docker daemon --insecure-registry ${REGISTRY} --registry-mirror=http://${REGISTRY}|" /lib/systemd/system/docker.service
     else
         echo "Unsupported Distro: $DISTRO" 1>&2
         exit 1
@@ -168,6 +169,7 @@ function configure_operator {
 
     pip install --upgrade "ansible>=2" python-openstackclient python-neutronclient tox
 
+    pip install ${KOLLA_ANSIBLE_PATH}
     pip install ${KOLLA_PATH}
 
     # Set selinux to permissive
@@ -177,8 +179,9 @@ function configure_operator {
     fi
 
     tox -c ${KOLLA_PATH}/tox.ini -e genconfig
-    cp -r ${KOLLA_PATH}/etc/kolla/ /etc/kolla
-    ${KOLLA_PATH}/tools/generate_passwords.py
+    cp -r ${KOLLA_ANSIBLE_PATH}/etc/kolla/ /etc/kolla
+    cp -r ${KOLLA_PATH}/etc/kolla/* /etc/kolla
+    ${KOLLA_ANSIBLE_PATH}/tools/generate_passwords.py
     mkdir -p /usr/share/kolla
     chown -R vagrant: /etc/kolla /usr/share/kolla
 
