@@ -6,11 +6,12 @@ set -o errexit
 # Enable unbuffered output for Ansible in Jenkins.
 export PYTHONUNBUFFERED=1
 
-source /etc/nodepool/provider
+. /etc/nodepool/provider
 
 NODEPOOL_MIRROR_HOST=${NODEPOOL_MIRROR_HOST:-mirror.$NODEPOOL_REGION.$NODEPOOL_CLOUD.openstack.org}
 NODEPOOL_MIRROR_HOST=$(echo $NODEPOOL_MIRROR_HOST|tr '[:upper:]' '[:lower:]')
 NODEPOOL_PYPI_MIRROR=${NODEPOOL_PYPI_MIRROR:-http://$NODEPOOL_MIRROR_HOST/pypi/simple}
+NODEPOOL_TARBALLS_MIRROR=${NODEPOOL_TARBALLS_MIRROR:-http://$NODEPOOL_MIRROR_HOST:8080/tarballs}
 
 GIT_PROJECT_DIR=$(mktemp -d)
 
@@ -51,6 +52,13 @@ EOF
     #   /home/jenkins/workspace/gate-kolla-ansible-dsvm-deploy-centos-source-centos-7-nv
 
     # NOTE(Jeffrey4l): use different a docker namespace name in case it pull image from hub.docker.io when deplying
+
+GATE_IMAGES="cron,fluentd,glance,haproxy,keepalived,keystone,kolla-toolbox,mariadb,memcached,neutron,nova,openvswitch,rabbitmq,horizon"
+
+if echo $ACTION | grep -q "ceph"; then
+GATE_IMAGES+=",ceph,cinder"
+fi
+
     cat <<EOF | sudo tee /etc/kolla/kolla-build.conf
 [DEFAULT]
 include_header = /etc/kolla/header
@@ -62,11 +70,11 @@ registry = 127.0.0.1:4000
 push = true
 
 [profiles]
-gate = cron,fluentd,glance,haproxy,keepalived,keystone,kolla-toolbox,mariadb,memcached,neutron,nova,openvswitch,rabbitmq,horizon
+gate = ${GATE_IMAGES}
 EOF
 
     if [[ "${DISTRO}" == "Debian" ]]; then
-        # Infra does not sign thier mirrors so we ignore gpg signing in the gate
+        # Infra does not sign their mirrors so we ignore gpg signing in the gate
         echo "RUN echo 'APT::Get::AllowUnauthenticated \"true\";' > /etc/apt/apt.conf" | sudo tee -a /etc/kolla/header
 
         # Optimize the repos to take advantage of the Infra provided mirrors for Ubuntu
@@ -118,15 +126,16 @@ function setup_ansible {
     mkdir /tmp/kolla
 
     # TODO(SamYaple): Move to virtualenv
-    sudo -H pip install -U "ansible>=2" "docker-py>=1.6.0" "python-openstackclient" "python-neutronclient" "ara"
+    sudo -H pip install -U "ansible>=2" "docker>=2.0.0" "python-openstackclient" "python-neutronclient" "ara"
     detect_distro
 
     setup_inventory
 
     sudo mkdir /etc/ansible
+    ara_location=$(python -c "import os,ara; print(os.path.dirname(ara.__file__))")
     sudo tee /etc/ansible/ansible.cfg<<EOF
 [defaults]
-callback_plugins = /usr/lib/python2.7/site-packages/ara/plugins/callbacks:\$VIRTUAL_ENV/lib/python2.7/site-packages/ara/plugins/callbacks
+callback_plugins = ${ara_location}/plugins/callbacks
 host_key_checking = False
 EOF
 
@@ -149,13 +158,15 @@ function setup_logging {
 }
 
 function prepare_images {
-    sudo docker run -d -p 4000:5000 --restart=always -v /tmp/kolla_registry/:/var/lib/registry --name registry registry:2
+    sudo docker run -d -p 4000:5000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry registry:2
 
     # NOTE(Jeffrey4l): Zuul adds all changes depend on to ZUUL_CHANGES
     # variable. if find "openstack/kolla:" string, it means this patch depends
     # on one of Kolla patch. Then build image by using Kolla's code.
     # Otherwise, pull images from tarballs.openstack.org site.
-    if echo "$ZUUL_CHANGES" | grep -q -i "openstack/kolla:"; then
+    # NOTE(inc0): Publisher variable is set when Kolla runs publisher jobs.
+    # When that happens we don't build images, we download them from temp location.
+    if echo "$ZUUL_CHANGES" | grep -i "openstack/kolla:" && ! [[ $PUBLISHER ]]; then
         pushd "${GIT_PROJECT_DIR}/kolla"
         sudo tox -e "build-${BASE_DISTRO}-${INSTALL_TYPE}"
         popd
@@ -163,8 +174,8 @@ function prepare_images {
         BRANCH=$(echo "$ZUUL_BRANCH" | cut -d/ -f2)
         filename=${BASE_DISTRO}-${INSTALL_TYPE}-registry-${BRANCH}.tar.gz
         wget -q -c -O "/tmp/$filename" \
-            "http://tarballs.openstack.org/kolla/images/$filename"
-        sudo tar xzf "/tmp/$filename" -C /tmp/kolla_registry
+            "${NODEPOOL_TARBALLS_MIRROR}/kolla/images/${TMP_REGISTRY}${filename}"
+        sudo tar xzf "/tmp/$filename" -C /opt/kolla_registry
     fi
 }
 
@@ -182,9 +193,14 @@ function sanity_check {
     neutron --debug agent-list
     tools/init-runonce
     nova --debug boot --poll --image $(openstack image list | awk '/cirros/ {print $2}') --nic net-id=$(openstack network list | awk '/demo-net/ {print $2}') --flavor 1 kolla_boot_test
+
     nova --debug list
     # If the status is not ACTIVE, print info and exit 1
     nova --debug show kolla_boot_test | awk '{buf=buf"\n"$0} $2=="status" && $4!="ACTIVE" {failed="yes"}; END {if (failed=="yes") {print buf; exit 1}}'
+    if echo $ACTION | grep -q "ceph"; then
+        openstack volume create --size 2 test_volume
+        openstack server add volume kolla_boot_test test_volume --device /dev/vdb
+    fi
 }
 
 function get_logs {
@@ -200,11 +216,15 @@ setup_ansible
 setup_config
 setup_node
 
-ansible-playbook -e type=$INSTALL_TYPE -e base=$BASE_DISTRO tests/ansible_generate_config.yml > /tmp/logs/ansible/generate_config
+ansible-playbook -e type=$INSTALL_TYPE -e base=$BASE_DISTRO -e action=$ACTION tests/ansible_generate_config.yml > /tmp/logs/ansible/generate_config
 tools/kolla-ansible -i ${RAW_INVENTORY} bootstrap-servers > /tmp/logs/ansible/bootstrap-servers
 sudo tools/generate_passwords.py
 prepare_images
 
+if echo $ACTION | grep -q "ceph"; then
+    ansible-playbook -i ${RAW_INVENTORY} tests/ansible_setup_ceph_disks.yml > /tmp/logs/ansible/setup_ceph_disks
+fi
+
 trap get_logs EXIT
 
 # Create dummy interface for neutron
