@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 # Copyright 2016 NEC Corporation
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -36,9 +36,6 @@ kd = imp.load_source('kolla_docker', kolla_docker_file)
 
 class ModuleArgsTest(base.BaseTestCase):
 
-    def setUp(self):
-        super(ModuleArgsTest, self).setUp()
-
     def test_module_args(self):
         argument_spec = dict(
             common_options=dict(required=False, type='dict', default=dict()),
@@ -65,6 +62,7 @@ class ModuleArgsTest(base.BaseTestCase):
             security_opt=dict(required=False, type='list', default=list()),
             pid_mode=dict(required=False, type='str', choices=['host', '']),
             privileged=dict(required=False, type='bool', default=False),
+            graceful_timeout=dict(required=False, type='int', default=10),
             remove_on_exit=dict(required=False, type='bool', default=True),
             restart_policy=dict(
                 required=False, type='str', choices=['no',
@@ -172,7 +170,7 @@ FAKE_DATA = {
 }
 
 
-@mock.patch("docker.Client")
+@mock.patch("docker.APIClient")
 def get_DockerWorker(mod_param, mock_dclient):
     module = mock.MagicMock()
     module.params = mod_param
@@ -228,6 +226,7 @@ class TestContainer(base.BaseTestCase):
         updated_cont_list = copy.deepcopy(self.fake_data['containers'])
         updated_cont_list.pop(0)
         self.dw.dc.containers.side_effect = [self.fake_data['containers'],
+                                             self.fake_data['containers'],
                                              self.fake_data['containers'],
                                              updated_cont_list,
                                              self.fake_data['containers']
@@ -270,7 +269,7 @@ class TestContainer(base.BaseTestCase):
 
         self.assertTrue(self.dw.changed)
         self.dw.dc.containers.assert_called_once_with(all=True)
-        self.dw.dc.stop.assert_called_once_with('my_container')
+        self.dw.dc.stop.assert_called_once_with('my_container', timeout=10)
 
     def test_stop_container_not_exists(self):
         self.dw = get_DockerWorker({'name': 'fake_container',
@@ -296,7 +295,7 @@ class TestContainer(base.BaseTestCase):
         self.assertTrue(self.dw.changed)
         self.dw.dc.containers.assert_called_once_with(all=True)
         self.dw.dc.inspect_container.assert_called_once_with('my_container')
-        self.dw.dc.stop.assert_called_once_with('my_container')
+        self.dw.dc.stop.assert_called_once_with('my_container', timeout=10)
         self.dw.dc.start.assert_called_once_with('my_container')
 
     def test_restart_container_not_exists(self):
@@ -482,6 +481,22 @@ class TestImage(base.BaseTestCase):
         self.dw.dc.images.assert_called_once_with()
         self.assertTrue(return_data)
 
+    def test_get_image_id_not_exists(self):
+        self.dw = get_DockerWorker(
+            {'image': 'myregistrydomain.com:5000/ubuntu:16.04'})
+        self.dw.dc.images.return_value = []
+
+        return_data = self.dw.get_image_id()
+        self.assertIsNone(return_data)
+
+    def test_get_image_id_exists(self):
+        self.dw = get_DockerWorker(
+            {'image': 'myregistrydomain.com:5000/ubuntu:16.04'})
+        self.dw.dc.images.return_value = ['sha256:47c3bdbcf99f0c1a36e4db']
+
+        return_data = self.dw.get_image_id()
+        self.assertEqual('sha256:47c3bdbcf99f0c1a36e4db', return_data)
+
     def test_pull_image_new(self):
         self.dw = get_DockerWorker(
             {'image': 'myregistrydomain.com:5000/ubuntu:16.04',
@@ -495,6 +510,10 @@ class TestImage(base.BaseTestCase):
             b'{"status":"Digest: sha256:47c3bdbcf99f0c1a36e4db"}\r\n',
             b'{"status":"Downloaded newer image for ubuntu:16.04"}\r\n'
         ]
+        self.dw.dc.images.side_effect = [
+            [],
+            ['sha256:47c3bdbcf99f0c1a36e4db']
+        ]
 
         self.dw.pull_image()
         self.dw.dc.pull.assert_called_once_with(
@@ -511,6 +530,10 @@ class TestImage(base.BaseTestCase):
             b'{"status":"Digest: sha256:47c3bdbf0c1a36e4db"}\r\n',
             b'{"status":"mage is up to date for ubuntu:16.04"}\r\n'
         ]
+        self.dw.dc.images.side_effect = [
+            ['sha256:47c3bdbcf99f0c1a36e4db'],
+            ['sha256:47c3bdbcf99f0c1a36e4db']
+        ]
 
         self.dw.pull_image()
         self.dw.dc.pull.assert_called_once_with(
@@ -519,22 +542,6 @@ class TestImage(base.BaseTestCase):
             stream=True)
         self.assertFalse(self.dw.changed)
 
-    def test_pull_image_unknown_status(self):
-        self.dw = get_DockerWorker(
-            {'image': 'myregistrydomain.com:5000/ubuntu:16.04'})
-        self.dw.dc.pull.return_value = [
-            b'{"status": "some random message"}\r\n']
-
-        self.dw.pull_image()
-        self.dw.dc.pull.assert_called_once_with(
-            repository='myregistrydomain.com:5000/ubuntu',
-            tag='16.04',
-            stream=True)
-        self.assertFalse(self.dw.changed)
-        self.dw.module.fail_json.assert_called_with(
-            msg='Unknown status message: some random message',
-            failed=True)
-
     def test_pull_image_not_exists(self):
         self.dw = get_DockerWorker(
             {'image': 'unknown:16.04'})
